##  Record Rationalization Decisions
**Note**
Evaluation methods, manual, semi-automated or fully automated, can only provide insights.
Always take the final application rationalization decisions in a conversation together with the affected stakeholders.
Bring all stakeholders together and evaluate if there are any dependencies or impacts you need to scope into your analysis and consider for the final decisions. You can also work with the stakeholders to answer the most important questions. For example:
  * Before sunsetting an application (elimination candidate), validate if it is interfacing with other applications, what data is exchanged, and if any business critical processes are affected when sunsetting the application. The Relations Explorer on the application Fact Sheet can be a good starting point for this.
  * Check if there are any planned or running initiatives impacting your analysis. Depending on your TIME classification, you might need to bring them forward, postpone them, or cancel them. A good reference is the roadmap report and as well as the transformations explorer.
  * Clarifying questions:
    * Will the functional and technical fit improve?
    * Will the lifecycle change?
    * How will the total cost of ownership of an application reduce/change?
    * What will the future hosting type be?
    * Which IT components will change?


The Decisions feature is part of the SAP LeanIX Architecture and Road Map Planning product. To learn more about decisions, read [Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD "Document and manage enterprise architecture decisions directly within SAP LeanIX, keeping all architecture-related information in one place.") and [Architecture Decision Templates](https://help.sap.com/docs/leanix/ea/architecture-decision-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Templates provide a predefined structure for architecture decisions, enhancing consistency and streamlining the creation process. Users with appropriate permissions can create custom templates that align with their organization’s decision types.").
To document your decisions, follow these steps:
  1. Go to Collaborations > Decisions.
  2. Select New Decision and select a template. The default template is Architecture Decision and you can create custom templates for your needs.
  3. Fill in the relevant details and select a status for this decision.
You can also come back to a decision and change details later.
![Filled out architecture decision form with fields for context, decision, consequences, fact sheets, approval, and review date](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3302596df46d459985937aa5882af370_LowRes.png)
